@@ -1,5 +1,5 @@
 # -*- coding:UTF-8 -*-
-from pyuts import ScrapyCommandU
+from pyuts.py_crawl.scrapyCommandU import ScrapyCommandU
 
 
 class Scrapycommandname(ScrapyCommandU):
