@@ -1,5 +1,6 @@
 # -*- coding: UTF-8 -*-
 from ..py_api_b import PyApiB
+import urllib.parse
 
 class AlgorithmU(PyApiB):
     """
@@ -38,15 +39,26 @@ class AlgorithmU(PyApiB):
         import base64
         return base64.b64decode(data)
       
-    def stepStr(self, dataStr, step=0):
-        bdataStr = bytes(dataStr,encoding='utf-8')
+    def stepStr(self, dataStr, step=0, isFiltOut=False):
+        bdataStr = bytes(dataStr,encoding='utf8')
         bdataStrs = []
         for b in bdataStr:
             bb = b+step
-            if bb > 255:
-                bb -= 255
+            if bb > 128:
+                if isFiltOut:
+                    continue
+                while bb > 128:
+                    bb -= 128
             elif bb < 0:
-                bb += 255
+                if isFiltOut:
+                    continue
+                while bb < 0:
+                    bb += 128
             bdataStrs.append(bb)
-        return str(bytes(bdataStrs),'utf-8')
-        
\ No newline at end of file
+        return str(bytes(bdataStrs),'utf8')
+    
+    def urlEncode(self, dataStr):
+        return urllib.parse.quote(dataStr)
+    
+    def urlDecode(self, dataStr):
+        return urllib.parse.unquote(dataStr)
\ No newline at end of file
