@@ -1,5 +1,9 @@
 # -*- coding: UTF-8 -*-
 from ..py_api_b import PyApiB
+from .algorithmU import AlgorithmU
+import sys
+import multiprocessing
+
 
 class CmdU(PyApiB):
     """
@@ -14,3 +18,8 @@ class CmdU(PyApiB):
         import subprocess
         subprocess.Popen(cmdline, shell=True, cwd=cwd).wait()
 
+    def getArgv(self, index, defV=None):
+        if len(sys.argv) > index:
+            return sys.argv[index]
+        else:
+            return defV
\ No newline at end of file
