@@ -42,7 +42,7 @@ class CtrlCU(PyApiB):
             del countTimeDict[key]
             setattr(self,"countTimeDict",countTimeDict)
         stt = during - (time.time() - st)
-        while stt > 0:
+        while stt > 0 and not self.isExit():
             time.sleep(1)
             stt -= 1
     
@@ -51,7 +51,7 @@ class CtrlCU(PyApiB):
             time.sleep(1)
 
     def isExit(self):
-        return self.is_sigint_up
+        return getattr(self,"is_sigint_up",False)
       
     def loopdo(self, fun, *args):
         self.on()
