@@ -6,6 +6,10 @@ class ProxyCrawlerU(PyApiB):
     """
     代理相关工具
     """
+    
+    crawlerEnable = True
+    """ 如果爬虫暂时不启用，将此设为False即可 """
+    
     @staticmethod
     def produce(key=None):
         return PyApiB._produce(key, __class__)
