@@ -19,6 +19,11 @@ class HttpHandlerU(tornado.web.RequestHandler, PyApiB):
     """
     postPath: str = None
     """ 复写post方法时需要给postPath付值，如：/test """
+    connectPath: str = None
+    """ 复写connect方法时需要给connectPath付值，如：/test """
+    
+    def getHttpServerU(self):
+        return getattr(self, "httpServerU")
 
     def returnData(self, data=None, code=200, msg='OK'):
         """
